#include <algorithm>
#include <cstdlib>
#include <cstring>
#include <deque>
#include <fstream>
#include <iostream>
#include <sstream>
#include <string>
#include <vector>

#define IMPOSSIBLE -1
#define FAIL -2

using namespace std;

const int maxn = 100000;

int k;
string s;
int s_freq[26];

int err_code;
string err_msg;

void calc_freq(const string& s, int* f)
{
    memset(f, 0, sizeof(int)*26);
    for (int i = 0; i < s.length(); i++) {
        f[s[i]-'a']++;
    }
}

int check(ifstream& f)
{
    string t;
    f >> t;
    int t_freq[26];

    if (!f) {
        err_msg = "looks like output is empty";
        err_code = 2;
        return FAIL;
    }

    if (t.length() != s.length()) {
        ostringstream ss;
        ss << "wrong length " << t.length();
        err_msg = ss.str();
        err_code = 2;
        return FAIL;
    }
    calc_freq(t, t_freq);
    for (int i = 0; i < 26; i++) {
        if (t_freq[i] != s_freq[i]) {
            ostringstream ss;
            ss << "wrong freq. for '" << char(i+'a') << "': " 
               << t_freq[i] << " instead of " << s_freq[i];
            err_msg = ss.str();
            err_code = 2;
            return FAIL;
        }
    }

    int last[26];
    int ans = t.length();
    memset(last, 0xff, sizeof(last));
    for (int i = 0; i < t.length(); i++) {
        int j = t[i] - 'a';
        if (last[j] != -1) {
            if (i - last[j] < ans)
                ans = i - last[j];
        }
        last[j] = i;
    }

    return ans;
}

int main(int argc, char* argv[])
{
    ifstream fin(argv[1]);
    ifstream fout(argv[2]);
    ifstream fans(argv[3]);

    fin >> s;
    calc_freq(s, s_freq);

    int jury_ans = check(fans);
    if (jury_ans == FAIL) {
        cout << "jury error: " << err_msg << endl;
        return 3;
    }

    int cont_ans = check(fout);
    if (cont_ans == FAIL) {
        cout << "contestant error: " << err_msg << endl;
        return err_code;
    }

    if (cont_ans > jury_ans) {
        cout << "contestant is better: " << cont_ans << " vs. " << jury_ans << endl;
        return 3;
    }

    if (cont_ans < jury_ans) {
        cout << "jury is better: " << cont_ans << " vs. " << jury_ans << endl;
        return 1;
    }

    cout << "ok ";
    if (jury_ans == IMPOSSIBLE) cout << "IMPOSSIBLE"; else cout << jury_ans;
    cout << endl;
    return 0;
}
